@@ -1,5 +1,5 @@
 package cyrillic;
-$curillic::VERSION = '1.21';
+$curillic::VERSION = '1.22';
 
 =head1 NAME
 
@@ -138,7 +138,7 @@ sub prepare
     my($src, $dst)=map $$_[2], @CODEPAGE{@_};
     substr($src, length $1, length $2) = '',
     substr($dst, length $1, length $2) = ''  while $dst =~ /^(.+?)( +)/;
-    substr($_, 66, 0) = '\x00-\x7f', s/-/\\-/g for $src, $dst;
+    s/-/\\-/g, substr($_, 66, 0) = '\x00-\x7f' for $src, $dst;
     return $src, $dst;
 }
 
